.. _user_guide_index:
.. _user_guide_introduction:

Introduction
============

If you are reading this user guide for the first time it is strongly recommended that you read the user guide
fully before experimenting with your own data files.


Much of the content has supplementary links to the reference documentation; you will not need to follow these
links in order to understand the guide but they may serve as a useful reference for future exploration.

.. only:: html

   Since later pages depend on earlier ones, try reading this user guide sequentially using the ``next`` and ``previous`` links.


* :doc:`iris_cubes`
* :doc:`loading_iris_cubes`
* :doc:`saving_iris_cubes`
* :doc:`navigating_a_cube`
* :doc:`subsetting_a_cube`
* :doc:`real_and_lazy_data`
* :doc:`plotting_a_cube`
* :doc:`interpolation_and_regridding`
* :doc:`merge_and_concat`
* :doc:`cube_statistics`
* :doc:`cube_maths`
* :doc:`citation`
* :doc:`code_maintenance`
